.. Welcome to SPECIES' documentation!
.. =================================
..
.. .. toctree::
..    :maxdepth: 2
..    :caption: Contents:
..
..
..
.. Indices and tables
.. ==================
..
.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`

.. _index:

Documentation for SPECIES
=========================

.. toctree::
   :maxdepth: 1

   installation
   examples
   about
   modules